==> haskell-logging-facade-0.3.1-393.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-logging-facade.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 logging-facade
version:              0.3.1
visibility:           public
id:                   logging-facade-0.3.1-2pTEnYtGGAfAGIRCLaP4MF
key:                  logging-facade-0.3.1-2pTEnYtGGAfAGIRCLaP4MF
license:              MIT
copyright:            (c) 2014-2021 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/sol/logging-facade#readme
synopsis:             Simple logging abstraction that allows multiple back-ends
description:          Simple logging abstraction that allows multiple back-ends
category:             System
abi:                  05b53fc148f2020a2cc00052bb237b72
exposed:              True
exposed-modules:
    System.Logging.Facade System.Logging.Facade.Class
    System.Logging.Facade.Sink System.Logging.Facade.Types

hidden-modules:       Paths_logging_facade
import-dirs:          /usr/lib/ghc-9.6.6/site-local/logging-facade-0.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/logging-facade-0.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/logging-facade-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-logging-facade
hs-libraries:         HSlogging-facade-0.3.1-2pTEnYtGGAfAGIRCLaP4MF
depends:
    base-4.18.2.1 call-stack-0.4.0-6YsJqSpqGk4Bu2nGz8R6vi
    transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-logging-facade/html/logging-facade.haddock

haddock-html:         /usr/share/doc/haskell-logging-facade/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-logging-facade-0.3.1-395-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-logging-facade.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 logging-facade
version:              0.3.1
visibility:           public
id:                   logging-facade-0.3.1-GVzTXTq5oFCKk7C7LqGMla
key:                  logging-facade-0.3.1-GVzTXTq5oFCKk7C7LqGMla
license:              MIT
copyright:            (c) 2014-2021 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/sol/logging-facade#readme
synopsis:             Simple logging abstraction that allows multiple back-ends
description:          Simple logging abstraction that allows multiple back-ends
category:             System
abi:                  c0f96f2af3d42e146b20e66dda8c1e59
exposed:              True
exposed-modules:
    System.Logging.Facade System.Logging.Facade.Class
    System.Logging.Facade.Sink System.Logging.Facade.Types

hidden-modules:       Paths_logging_facade
import-dirs:          /usr/lib/ghc-9.6.6/site-local/logging-facade-0.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/logging-facade-0.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/logging-facade-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-logging-facade
hs-libraries:         HSlogging-facade-0.3.1-GVzTXTq5oFCKk7C7LqGMla
depends:
    base-4.18.2.1 call-stack-0.4.0-2bP2isqo6m56I7hpBeHX0O
    transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-logging-facade/html/logging-facade.haddock

haddock-html:         /usr/share/doc/haskell-logging-facade/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
